% ************************************
% Parameter Values used for GDL Model
% Jason Siegel, Denise McKay
% Summer 2007
%
% Used for 24 cell SERC stack
% Gore 5620 MEAs, ETek ELATs
% ************************************

% ************************************
%   Stack properties
% ************************************
FC_NUMBEROFCELLS=24.0;  % number of cells in stack
FC_ACTIVEAREA=300.0;    % cell nominal active area (cm^2)
FC_ACTIVEAREA_M2=FC_ACTIVEAREA/10000 ; % Cell nominal active area (m^2)

FC_ANODE_VOLUME=0.00043;                % total stack anode volume (m3)
FC_ANODE_OUTLET_FLOW_CONSTANT=9.3440e-7;% anode outlet channel orifice constant (kg/s/Pa)
FC_ANODE_INLET_FLOW_CONSTANT=9.3440e-7 ;% anode inlet channel orifice constant (kg/s/Pa)
% Note: Due to hardware, there is now way to measure anode orifice
%       constants, we assume the k_an=k_ca, which results in H2 flow rates
%       close to supersonic flow, the orifice constants were then scaled
%       down by a factor of 1.2 to predict "reasonable" H2 mass flows
%       during purges

FC_CATHODE_VOLUME =0.00038;             % total stack cathode volume (m3)
FC_CATHODE_OUTLET_FLOW_CONSTANT=11.31e-7;% cathode outlet channel orifice constant (kg/s/Pa)
FC_CATHODE_INLET_FLOW_CONSTANT= 11.31e-7;% cathode inlet channel orifice constant (kg/s/Pa)

FC_ANODE_OM_VOLUME=(0.00043/2+6*12 * 2.54 /100*pi*(3/8/2* 2.54 /100)^2); % anode outlet manifold volume (m3)
Purge_K=(11.31e-7)*10;%                 % anode outlet manifold orifice constant (kg/s/Pa)

% ***********************************
%   Air properties
% ***********************************
R_G_U=8.3145;               % Universal Gas Constant (J/(mol*K))
CP=1004.0;                  % specific heat of air (J/(kg*K))
CV=718.0;                   % specific heat of water vapor (J/(kg*K))
GAMMA=1.4;                  % ratio of specific heat cnst pressure to cnst volume
RHO=1.23;                   % air density at STP (kg/m^3)
OXYGENMOLARMASS=32.0e-3;    % Oxygen Molar Mass (kg/mol)
NITROGENMOLARMASS=28.0e-3;  % Nitrogen Molar Mass (kg/mol)
OXYGENGASCONSTANT=R_G_U/OXYGENMOLARMASS;     % Oxygen Gas Constant (J/(kg*K))
NITROGENGASCONSTANT=R_G_U/NITROGENMOLARMASS; % Nitrogen Gas Constant (J/(kg*K))
OMF_ca_in=0.21;             % mole fraction of oxygen in air
AIRMOLARMASS=OMF_ca_in*OXYGENMOLARMASS+(1-OMF_ca_in)*NITROGENMOLARMASS;% Air Molar Mass (kg/mol)

% ***********************************
%   Water properties
% ***********************************
VAPORMOLARMASS=18.02e-3;    % Water Vapor Molar Mass (kg/mol)
VAPORGASCONSTANT=R_G_U/(VAPORMOLARMASS);% Water Vapor Gas Constant (J/(kg*K))
WATERDENSITY=997.0;         % liquid water density (kg/m^3)
H20_L_VISC=0.000405;        % liquid water viscosity, Kaviany (kg/(m*s))

% ***********************************
%   Hydrogen properties
% ***********************************
HYDROGENMOLARMASS=2.016e-3; % Hydrogen Molar Mass (kg/mol)
HYDROGENGASCONSTANT=R_G_U/(HYDROGENMOLARMASS); % Hydrogen gas constant (J/(kg*K))

% ***********************************
%   Electrochemistry
% ***********************************
FARADAYS=96485.0;           % Faradays constant (C/mol e-)

% ***************************
%   Gas Diffusion Layer
% ***************************
GDL_THICKNESS=0.0005;       % thickness of single GDL (m)
GDL_POR=0.5;                % GDL porosity, Kaviany
D_O2=3.0300e-5;             % oxygen diffusion coeff, Kaviany (m2/s)
D_V=3.4500e-5;              % water vapor diffusion coeff, Kaviany (m2/s)
D_H2=1.1400e-4;             % hydrogen diffusion coeff, Kaviany (m2/s)
imobile_sat=0.1;            % Immobile saturation Limit, Kaviany
H20_SURF_T=0.0644;          % surface tension, Kaviany (N/m}
GDL_AREA=FC_ACTIVEAREA_M2*GDL_POR; % GDL surface Area (m^2)
N_GDL_SECs=3;               % number of discrete GDL sections
delta_y=GDL_THICKNESS/N_GDL_SECs; % thickness of discrete section (m)
V_P=(FC_ACTIVEAREA_M2)*GDL_THICKNESS*GDL_POR/N_GDL_SECs; % volume of pore space in each section (m^3)
Alg_V= 1000;                % Part of evaporation rate, gamma=0.9*Alg_V, Kaviany

Kk=6.0;
df=7e-6;
K_PERM=(df*df*GDL_POR*GDL_POR*GDL_POR/(16*Kk*(1-GDL_POR)*(1-GDL_POR) )); % absolute permiability, Kaviany (m^2)
%K_PERM=2.55e-13; % absolute permiability, Kaviany (m^2)           

% ***************************
%   Membrane
% ***************************
MEMBRANEDRYDENSITY=0.0019;  % membrane dry density (kg/cm3)
MEMBRANEDRYEQVWEIGHT=1.0;   % membrane dry equivalent weight (kg/mol)
MEMBRANETHICKNESS=0.00381;  % membrane thickness including catalyst layers, 1.5 mils (cm)
lambda_max_diff=16.8;       % maximum water content when equilibrated with liquid water, at activity a=3, T=30C, (Springer1991JECS) linear Interp from 3>a>1.
lambda_max_drag=22;         % maximum water content when equilibrated with liquid water, at activity a=3, T=80C (Springer1991JECS)

% ***************************
%    Voltage parameters
% ***************************
h0 = -241980;       % change in enthalpy, water in vapor phase (J/mol)
s0 = -44.43;        % change in entropy, water in vapor phase (J/(mol K))
T0 = 298.15;        % reference temperature (K)
p0 = 101325;        % reference pressure (Pa)
Ec=66e3;            % activation energy (J/mol)
iloss=0.001;        % loss current density (A/cm2)
b2=1268;            % ohmic resistance parameter, Springer
b11=0.005139;       % ohmic resistance tuned parameter, Springer
b12=0.00326;        % ohmic resistance tuned parameter, Springer

% ***************************
%    Identified Parameters
% ***************************
K1 = 1.165481158348826;     % voltage parameter 1
K2 = 4.443112548896407e-06; % voltage parameter 2
K3 = 1.783746791063606;     % voltage parameter 3
K4 = 3.267597642026195;     % voltage parameter 4

alpha_n_d = 1;              % scaling factor for electroosmotic drag
alpha_D_w =12.0;            % scaling factor for back diffusion
%t_w =0.13146;               % liquid water film thickness at GDL-channel interface (mm)
t_w =0.12;               % liquid water film thickness at GDL-channel interface (mm)

